.. _pagetemplate_api_module:

:mod:`chameleon.zpt`
--------------------------

``PageTemplate*`` constructors create templates from XML files.

.. automodule:: chameleon.zpt.template

  .. autoclass:: chameleon.zpt.template.PageTemplate

  .. autoclass:: chameleon.zpt.template.PageTemplateFile

A template loader class is provided (for use with Pylons and other
platforms).
  
.. automodule:: chameleon.zpt.loader

  .. autoclass:: chameleon.zpt.loader.TemplateLoader
